# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'page_feed_asset_set_id': 'int',
        'page_feed_asset_id': 'int',
        'approval_status': 'PageFeedAssetServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]',
        'disapproval_reason_comment': 'str',
        'page_feed_asset_custom_label': 'str',
        'page_feed_asset_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'page_feed_asset_set_id': 'pageFeedAssetSetId',
        'page_feed_asset_id': 'pageFeedAssetId',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'disapproval_reason_comment': 'disapprovalReasonComment',
        'page_feed_asset_custom_label': 'pageFeedAssetCustomLabel',
        'page_feed_asset_url': 'pageFeedAssetUrl'
    }

    def __init__(self, account_id=None, page_feed_asset_set_id=None, page_feed_asset_id=None, approval_status=None, disapproval_reason_codes=None, disapproval_reason_comment=None, page_feed_asset_custom_label=None, page_feed_asset_url=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._page_feed_asset_set_id = None
        self._page_feed_asset_id = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self._disapproval_reason_comment = None
        self._page_feed_asset_custom_label = None
        self._page_feed_asset_url = None
        self.discriminator = None

        self.account_id = account_id
        self.page_feed_asset_set_id = page_feed_asset_set_id
        self.page_feed_asset_id = page_feed_asset_id
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes
        self.disapproval_reason_comment = disapproval_reason_comment
        self.page_feed_asset_custom_label = page_feed_asset_custom_label
        self.page_feed_asset_url = page_feed_asset_url

    @property
    def account_id(self):
        """Gets the account_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PageFeedAsset.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def page_feed_asset_set_id(self):
        """Gets the page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :return: The page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_set_id

    @page_feed_asset_set_id.setter
    def page_feed_asset_set_id(self, page_feed_asset_set_id):
        """Sets the page_feed_asset_set_id of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :param page_feed_asset_set_id: The page_feed_asset_set_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_set_id = page_feed_asset_set_id

    @property
    def page_feed_asset_id(self):
        """Gets the page_feed_asset_id of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットID</div> <div lang=\"en\">PageFeedAsset ID.</div>   # noqa: E501

        :return: The page_feed_asset_id of this PageFeedAsset.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_id

    @page_feed_asset_id.setter
    def page_feed_asset_id(self, page_feed_asset_id):
        """Sets the page_feed_asset_id of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットID</div> <div lang=\"en\">PageFeedAsset ID.</div>   # noqa: E501

        :param page_feed_asset_id: The page_feed_asset_id of this PageFeedAsset.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_id = page_feed_asset_id

    @property
    def approval_status(self):
        """Gets the approval_status of this PageFeedAsset.  # noqa: E501


        :return: The approval_status of this PageFeedAsset.  # noqa: E501
        :rtype: PageFeedAssetServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this PageFeedAsset.


        :param approval_status: The approval_status of this PageFeedAsset.  # noqa: E501
        :type: PageFeedAssetServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">審査否認理由コード</div> <div lang=\"en\">Codes of disapproval reason.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this PageFeedAsset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this PageFeedAsset.

        <div lang=\"ja\">審査否認理由コード</div> <div lang=\"en\">Codes of disapproval reason.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this PageFeedAsset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def disapproval_reason_comment(self):
        """Gets the disapproval_reason_comment of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">審査否認理由のコメント</div> <div lang=\"en\">Comment of disapproval reason.</div>   # noqa: E501

        :return: The disapproval_reason_comment of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._disapproval_reason_comment

    @disapproval_reason_comment.setter
    def disapproval_reason_comment(self, disapproval_reason_comment):
        """Sets the disapproval_reason_comment of this PageFeedAsset.

        <div lang=\"ja\">審査否認理由のコメント</div> <div lang=\"en\">Comment of disapproval reason.</div>   # noqa: E501

        :param disapproval_reason_comment: The disapproval_reason_comment of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._disapproval_reason_comment = disapproval_reason_comment

    @property
    def page_feed_asset_custom_label(self):
        """Gets the page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットのカスタムラベル<br> 複数ある場合はカンマ区切り</div> <div lang=\"en\">Custom label of page feed asset.<br> If multiple, comma separated.</div>   # noqa: E501

        :return: The page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._page_feed_asset_custom_label

    @page_feed_asset_custom_label.setter
    def page_feed_asset_custom_label(self, page_feed_asset_custom_label):
        """Sets the page_feed_asset_custom_label of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットのカスタムラベル<br> 複数ある場合はカンマ区切り</div> <div lang=\"en\">Custom label of page feed asset.<br> If multiple, comma separated.</div>   # noqa: E501

        :param page_feed_asset_custom_label: The page_feed_asset_custom_label of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._page_feed_asset_custom_label = page_feed_asset_custom_label

    @property
    def page_feed_asset_url(self):
        """Gets the page_feed_asset_url of this PageFeedAsset.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットのURL</div> <div lang=\"en\">Url of page feed asset.</div>   # noqa: E501

        :return: The page_feed_asset_url of this PageFeedAsset.  # noqa: E501
        :rtype: str
        """
        return self._page_feed_asset_url

    @page_feed_asset_url.setter
    def page_feed_asset_url(self, page_feed_asset_url):
        """Sets the page_feed_asset_url of this PageFeedAsset.

        <div lang=\"ja\">ページフィードアセットのURL</div> <div lang=\"en\">Url of page feed asset.</div>   # noqa: E501

        :param page_feed_asset_url: The page_feed_asset_url of this PageFeedAsset.  # noqa: E501
        :type: str
        """

        self._page_feed_asset_url = page_feed_asset_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAsset):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignServiceBiddingScheme(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bidding_strategy_type': 'CampaignServiceBiddingStrategyType',
        'cpc_bidding_scheme': 'CampaignServiceCpcBiddingScheme',
        'target_cpa_bidding_scheme': 'CampaignServiceTargetCpaBiddingScheme',
        'target_roas_bidding_scheme': 'CampaignServiceTargetRoasBiddingScheme',
        'maximize_clicks_bidding_scheme': 'CampaignServiceMaximizeClicksBiddingScheme',
        'target_impression_share_scheme': 'CampaignServiceTargetImpressionShareScheme',
        'maximize_conversions_bidding_scheme': 'CampaignServiceMaximizeConversionsBiddingScheme',
        'maximize_conversion_value_bidding_scheme': 'CampaignServiceMaximizeConversionValueBiddingScheme'
    }

    attribute_map = {
        'bidding_strategy_type': 'biddingStrategyType',
        'cpc_bidding_scheme': 'cpcBiddingScheme',
        'target_cpa_bidding_scheme': 'targetCpaBiddingScheme',
        'target_roas_bidding_scheme': 'targetRoasBiddingScheme',
        'maximize_clicks_bidding_scheme': 'maximizeClicksBiddingScheme',
        'target_impression_share_scheme': 'targetImpressionShareScheme',
        'maximize_conversions_bidding_scheme': 'maximizeConversionsBiddingScheme',
        'maximize_conversion_value_bidding_scheme': 'maximizeConversionValueBiddingScheme'
    }

    def __init__(self, bidding_strategy_type=None, cpc_bidding_scheme=None, target_cpa_bidding_scheme=None, target_roas_bidding_scheme=None, maximize_clicks_bidding_scheme=None, target_impression_share_scheme=None, maximize_conversions_bidding_scheme=None, maximize_conversion_value_bidding_scheme=None, local_vars_configuration=None):  # noqa: E501
        """CampaignServiceBiddingScheme - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bidding_strategy_type = None
        self._cpc_bidding_scheme = None
        self._target_cpa_bidding_scheme = None
        self._target_roas_bidding_scheme = None
        self._maximize_clicks_bidding_scheme = None
        self._target_impression_share_scheme = None
        self._maximize_conversions_bidding_scheme = None
        self._maximize_conversion_value_bidding_scheme = None
        self.discriminator = None

        self.bidding_strategy_type = bidding_strategy_type
        self.cpc_bidding_scheme = cpc_bidding_scheme
        self.target_cpa_bidding_scheme = target_cpa_bidding_scheme
        self.target_roas_bidding_scheme = target_roas_bidding_scheme
        self.maximize_clicks_bidding_scheme = maximize_clicks_bidding_scheme
        self.target_impression_share_scheme = target_impression_share_scheme
        self.maximize_conversions_bidding_scheme = maximize_conversions_bidding_scheme
        self.maximize_conversion_value_bidding_scheme = maximize_conversion_value_bidding_scheme

    @property
    def bidding_strategy_type(self):
        """Gets the bidding_strategy_type of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The bidding_strategy_type of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategyType
        """
        return self._bidding_strategy_type

    @bidding_strategy_type.setter
    def bidding_strategy_type(self, bidding_strategy_type):
        """Sets the bidding_strategy_type of this CampaignServiceBiddingScheme.


        :param bidding_strategy_type: The bidding_strategy_type of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceBiddingStrategyType
        """

        self._bidding_strategy_type = bidding_strategy_type

    @property
    def cpc_bidding_scheme(self):
        """Gets the cpc_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The cpc_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceCpcBiddingScheme
        """
        return self._cpc_bidding_scheme

    @cpc_bidding_scheme.setter
    def cpc_bidding_scheme(self, cpc_bidding_scheme):
        """Sets the cpc_bidding_scheme of this CampaignServiceBiddingScheme.


        :param cpc_bidding_scheme: The cpc_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceCpcBiddingScheme
        """

        self._cpc_bidding_scheme = cpc_bidding_scheme

    @property
    def target_cpa_bidding_scheme(self):
        """Gets the target_cpa_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The target_cpa_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceTargetCpaBiddingScheme
        """
        return self._target_cpa_bidding_scheme

    @target_cpa_bidding_scheme.setter
    def target_cpa_bidding_scheme(self, target_cpa_bidding_scheme):
        """Sets the target_cpa_bidding_scheme of this CampaignServiceBiddingScheme.


        :param target_cpa_bidding_scheme: The target_cpa_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceTargetCpaBiddingScheme
        """

        self._target_cpa_bidding_scheme = target_cpa_bidding_scheme

    @property
    def target_roas_bidding_scheme(self):
        """Gets the target_roas_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The target_roas_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceTargetRoasBiddingScheme
        """
        return self._target_roas_bidding_scheme

    @target_roas_bidding_scheme.setter
    def target_roas_bidding_scheme(self, target_roas_bidding_scheme):
        """Sets the target_roas_bidding_scheme of this CampaignServiceBiddingScheme.


        :param target_roas_bidding_scheme: The target_roas_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceTargetRoasBiddingScheme
        """

        self._target_roas_bidding_scheme = target_roas_bidding_scheme

    @property
    def maximize_clicks_bidding_scheme(self):
        """Gets the maximize_clicks_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The maximize_clicks_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceMaximizeClicksBiddingScheme
        """
        return self._maximize_clicks_bidding_scheme

    @maximize_clicks_bidding_scheme.setter
    def maximize_clicks_bidding_scheme(self, maximize_clicks_bidding_scheme):
        """Sets the maximize_clicks_bidding_scheme of this CampaignServiceBiddingScheme.


        :param maximize_clicks_bidding_scheme: The maximize_clicks_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceMaximizeClicksBiddingScheme
        """

        self._maximize_clicks_bidding_scheme = maximize_clicks_bidding_scheme

    @property
    def target_impression_share_scheme(self):
        """Gets the target_impression_share_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The target_impression_share_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceTargetImpressionShareScheme
        """
        return self._target_impression_share_scheme

    @target_impression_share_scheme.setter
    def target_impression_share_scheme(self, target_impression_share_scheme):
        """Sets the target_impression_share_scheme of this CampaignServiceBiddingScheme.


        :param target_impression_share_scheme: The target_impression_share_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceTargetImpressionShareScheme
        """

        self._target_impression_share_scheme = target_impression_share_scheme

    @property
    def maximize_conversions_bidding_scheme(self):
        """Gets the maximize_conversions_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The maximize_conversions_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceMaximizeConversionsBiddingScheme
        """
        return self._maximize_conversions_bidding_scheme

    @maximize_conversions_bidding_scheme.setter
    def maximize_conversions_bidding_scheme(self, maximize_conversions_bidding_scheme):
        """Sets the maximize_conversions_bidding_scheme of this CampaignServiceBiddingScheme.


        :param maximize_conversions_bidding_scheme: The maximize_conversions_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceMaximizeConversionsBiddingScheme
        """

        self._maximize_conversions_bidding_scheme = maximize_conversions_bidding_scheme

    @property
    def maximize_conversion_value_bidding_scheme(self):
        """Gets the maximize_conversion_value_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501


        :return: The maximize_conversion_value_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :rtype: CampaignServiceMaximizeConversionValueBiddingScheme
        """
        return self._maximize_conversion_value_bidding_scheme

    @maximize_conversion_value_bidding_scheme.setter
    def maximize_conversion_value_bidding_scheme(self, maximize_conversion_value_bidding_scheme):
        """Sets the maximize_conversion_value_bidding_scheme of this CampaignServiceBiddingScheme.


        :param maximize_conversion_value_bidding_scheme: The maximize_conversion_value_bidding_scheme of this CampaignServiceBiddingScheme.  # noqa: E501
        :type: CampaignServiceMaximizeConversionValueBiddingScheme
        """

        self._maximize_conversion_value_bidding_scheme = maximize_conversion_value_bidding_scheme

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignServiceBiddingScheme):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignServiceBiddingScheme):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AuditLogServiceJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'date_range': 'AuditLogServiceDateRange',
        'encoding': 'AuditLogServiceEncoding',
        'event_selector': 'list[AuditLogServiceEventSelector]',
        'job_id': 'int',
        'job_name': 'str',
        'job_status': 'AuditLogServiceJobStatus',
        'lang': 'AuditLogServiceLang',
        'output': 'AuditLogServiceOutput',
        'source_type': 'AuditLogServiceSourceType'
    }

    attribute_map = {
        'account_id': 'accountId',
        'date_range': 'dateRange',
        'encoding': 'encoding',
        'event_selector': 'eventSelector',
        'job_id': 'jobId',
        'job_name': 'jobName',
        'job_status': 'jobStatus',
        'lang': 'lang',
        'output': 'output',
        'source_type': 'sourceType'
    }

    def __init__(self, account_id=None, date_range=None, encoding=None, event_selector=None, job_id=None, job_name=None, job_status=None, lang=None, output=None, source_type=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogServiceJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._date_range = None
        self._encoding = None
        self._event_selector = None
        self._job_id = None
        self._job_name = None
        self._job_status = None
        self._lang = None
        self._output = None
        self._source_type = None
        self.discriminator = None

        self.account_id = account_id
        self.date_range = date_range
        self.encoding = encoding
        self.event_selector = event_selector
        self.job_id = job_id
        self.job_name = job_name
        self.job_status = job_status
        self.lang = lang
        self.output = output
        self.source_type = source_type

    @property
    def account_id(self):
        """Gets the account_id of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this AuditLogServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AuditLogServiceJob.

        <div lang=\"ja\">アカウントIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this AuditLogServiceJob.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def date_range(self):
        """Gets the date_range of this AuditLogServiceJob.  # noqa: E501


        :return: The date_range of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceDateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this AuditLogServiceJob.


        :param date_range: The date_range of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceDateRange
        """

        self._date_range = date_range

    @property
    def encoding(self):
        """Gets the encoding of this AuditLogServiceJob.  # noqa: E501


        :return: The encoding of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceEncoding
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this AuditLogServiceJob.


        :param encoding: The encoding of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceEncoding
        """

        self._encoding = encoding

    @property
    def event_selector(self):
        """Gets the event_selector of this AuditLogServiceJob.  # noqa: E501


        :return: The event_selector of this AuditLogServiceJob.  # noqa: E501
        :rtype: list[AuditLogServiceEventSelector]
        """
        return self._event_selector

    @event_selector.setter
    def event_selector(self, event_selector):
        """Sets the event_selector of this AuditLogServiceJob.


        :param event_selector: The event_selector of this AuditLogServiceJob.  # noqa: E501
        :type: list[AuditLogServiceEventSelector]
        """

        self._event_selector = event_selector

    @property
    def job_id(self):
        """Gets the job_id of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Job ID.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The job_id of this AuditLogServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this AuditLogServiceJob.

        <div lang=\"ja\">ジョブIDです。<br>このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Job ID.<br>Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param job_id: The job_id of this AuditLogServiceJob.  # noqa: E501
        :type: int
        """

        self._job_id = job_id

    @property
    def job_name(self):
        """Gets the job_name of this AuditLogServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブ名です。<br>このフィールドは、省略可能となります。</div> <div lang=\"en\">Name of job.<br>This field is optional.</div>   # noqa: E501

        :return: The job_name of this AuditLogServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this AuditLogServiceJob.

        <div lang=\"ja\">ジョブ名です。<br>このフィールドは、省略可能となります。</div> <div lang=\"en\">Name of job.<br>This field is optional.</div>   # noqa: E501

        :param job_name: The job_name of this AuditLogServiceJob.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_status(self):
        """Gets the job_status of this AuditLogServiceJob.  # noqa: E501


        :return: The job_status of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this AuditLogServiceJob.


        :param job_status: The job_status of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceJobStatus
        """

        self._job_status = job_status

    @property
    def lang(self):
        """Gets the lang of this AuditLogServiceJob.  # noqa: E501


        :return: The lang of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceLang
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this AuditLogServiceJob.


        :param lang: The lang of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceLang
        """

        self._lang = lang

    @property
    def output(self):
        """Gets the output of this AuditLogServiceJob.  # noqa: E501


        :return: The output of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceOutput
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this AuditLogServiceJob.


        :param output: The output of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceOutput
        """

        self._output = output

    @property
    def source_type(self):
        """Gets the source_type of this AuditLogServiceJob.  # noqa: E501


        :return: The source_type of this AuditLogServiceJob.  # noqa: E501
        :rtype: AuditLogServiceSourceType
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this AuditLogServiceJob.


        :param source_type: The source_type of this AuditLogServiceJob.  # noqa: E501
        :type: AuditLogServiceSourceType
        """

        self._source_type = source_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogServiceJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogServiceJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class RetargetingListServiceRuleItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'custom_key_rule_item': 'RetargetingListServiceCustomKeyRuleItem',
        'rule_operator': 'RetargetingListServiceRuleOperator',
        'rule_type': 'RetargetingListServiceRuleType',
        'url_rule_item': 'RetargetingListServiceUrlRuleItem',
        'value': 'str'
    }

    attribute_map = {
        'custom_key_rule_item': 'customKeyRuleItem',
        'rule_operator': 'ruleOperator',
        'rule_type': 'ruleType',
        'url_rule_item': 'urlRuleItem',
        'value': 'value'
    }

    def __init__(self, custom_key_rule_item=None, rule_operator=None, rule_type=None, url_rule_item=None, value=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceRuleItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._custom_key_rule_item = None
        self._rule_operator = None
        self._rule_type = None
        self._url_rule_item = None
        self._value = None
        self.discriminator = None

        self.custom_key_rule_item = custom_key_rule_item
        self.rule_operator = rule_operator
        self.rule_type = rule_type
        self.url_rule_item = url_rule_item
        self.value = value

    @property
    def custom_key_rule_item(self):
        """Gets the custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceCustomKeyRuleItem
        """
        return self._custom_key_rule_item

    @custom_key_rule_item.setter
    def custom_key_rule_item(self, custom_key_rule_item):
        """Sets the custom_key_rule_item of this RetargetingListServiceRuleItem.


        :param custom_key_rule_item: The custom_key_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceCustomKeyRuleItem
        """

        self._custom_key_rule_item = custom_key_rule_item

    @property
    def rule_operator(self):
        """Gets the rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceRuleOperator
        """
        return self._rule_operator

    @rule_operator.setter
    def rule_operator(self, rule_operator):
        """Sets the rule_operator of this RetargetingListServiceRuleItem.


        :param rule_operator: The rule_operator of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceRuleOperator
        """

        self._rule_operator = rule_operator

    @property
    def rule_type(self):
        """Gets the rule_type of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The rule_type of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceRuleType
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """Sets the rule_type of this RetargetingListServiceRuleItem.


        :param rule_type: The rule_type of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceRuleType
        """

        self._rule_type = rule_type

    @property
    def url_rule_item(self):
        """Gets the url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501


        :return: The url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: RetargetingListServiceUrlRuleItem
        """
        return self._url_rule_item

    @url_rule_item.setter
    def url_rule_item(self, url_rule_item):
        """Sets the url_rule_item of this RetargetingListServiceRuleItem.


        :param url_rule_item: The url_rule_item of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: RetargetingListServiceUrlRuleItem
        """

        self._url_rule_item = url_rule_item

    @property
    def value(self):
        """Gets the value of this RetargetingListServiceRuleItem.  # noqa: E501

        <div lang=\"ja\">評価値です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※括弧（()）、シングルクォート（&#39;）、ダブルクォート（&#34;）、タブ（\\t）は利用できません。<br> ※250文字まで指定可能です。</div> <div lang=\"en\">Evaluation value.<br> *Cannot use: bracket, single quote, double quote, and tab.<br> *Can select up to 250 characters.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The value of this RetargetingListServiceRuleItem.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this RetargetingListServiceRuleItem.

        <div lang=\"ja\">評価値です。<br> ADDおよびSET時、このフィールドは必須となります。<br> ※括弧（()）、シングルクォート（&#39;）、ダブルクォート（&#34;）、タブ（\\t）は利用できません。<br> ※250文字まで指定可能です。</div> <div lang=\"en\">Evaluation value.<br> *Cannot use: bracket, single quote, double quote, and tab.<br> *Can select up to 250 characters.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :param value: The value of this RetargetingListServiceRuleItem.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceRuleItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceRuleItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ConversionTrackerServiceAppLinkConversion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'app_vendor_id': 'str',
        'app_id': 'str',
        'app_link_platform': 'ConversionTrackerServiceAppLinkPlatform',
        'app_event_type': 'str',
        'advanced_snippet': 'str'
    }

    attribute_map = {
        'app_vendor_id': 'appVendorId',
        'app_id': 'appId',
        'app_link_platform': 'appLinkPlatform',
        'app_event_type': 'appEventType',
        'advanced_snippet': 'advancedSnippet'
    }

    def __init__(self, app_vendor_id=None, app_id=None, app_link_platform=None, app_event_type=None, advanced_snippet=None, local_vars_configuration=None):  # noqa: E501
        """ConversionTrackerServiceAppLinkConversion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._app_vendor_id = None
        self._app_id = None
        self._app_link_platform = None
        self._app_event_type = None
        self._advanced_snippet = None
        self.discriminator = None

        self.app_vendor_id = app_vendor_id
        self.app_id = app_id
        self.app_link_platform = app_link_platform
        self.app_event_type = app_event_type
        self.advanced_snippet = advanced_snippet

    @property
    def app_vendor_id(self):
        """Gets the app_vendor_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501

        <div lang=\"ja\">アプリ計測ベンダー識別子です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application vendor ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The app_vendor_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :rtype: str
        """
        return self._app_vendor_id

    @app_vendor_id.setter
    def app_vendor_id(self, app_vendor_id):
        """Sets the app_vendor_id of this ConversionTrackerServiceAppLinkConversion.

        <div lang=\"ja\">アプリ計測ベンダー識別子です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application vendor ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param app_vendor_id: The app_vendor_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :type: str
        """

        self._app_vendor_id = app_vendor_id

    @property
    def app_id(self):
        """Gets the app_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501

        <div lang=\"ja\">アプリケーションIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The app_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this ConversionTrackerServiceAppLinkConversion.

        <div lang=\"ja\">アプリケーションIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param app_id: The app_id of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def app_link_platform(self):
        """Gets the app_link_platform of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501


        :return: The app_link_platform of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :rtype: ConversionTrackerServiceAppLinkPlatform
        """
        return self._app_link_platform

    @app_link_platform.setter
    def app_link_platform(self, app_link_platform):
        """Sets the app_link_platform of this ConversionTrackerServiceAppLinkConversion.


        :param app_link_platform: The app_link_platform of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :type: ConversionTrackerServiceAppLinkPlatform
        """

        self._app_link_platform = app_link_platform

    @property
    def app_event_type(self):
        """Gets the app_event_type of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501

        <div lang=\"ja\">アプリイベントタイプです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application event type.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The app_event_type of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :rtype: str
        """
        return self._app_event_type

    @app_event_type.setter
    def app_event_type(self, app_event_type):
        """Sets the app_event_type of this ConversionTrackerServiceAppLinkConversion.

        <div lang=\"ja\">アプリイベントタイプです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Application event type.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param app_event_type: The app_event_type of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :type: str
        """

        self._app_event_type = app_event_type

    @property
    def advanced_snippet(self):
        """Gets the advanced_snippet of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501

        <div lang=\"ja\">   リニューアル版のコンバージョンタグは、従来のタグよりもブラウザーなどの環境の影響を受けづらい新しいフォーマットです。<br>   詳細は以下のヘルプを参照してください。<br>   ・<a href=\"https://ads-help.yahoo-net.jp/s/article/H000045014?language=ja\">コンバージョン測定とは</a><br>   このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">   The new format of conversion tag avoids the impacts such as changes made to the browser. <br>   See also the help below.<br>   * <a href=\"https://ads-help.yahoo-net.jp/s/article/H000045014?language=en_US\">Conversion Analytics</a><br>   Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :return: The advanced_snippet of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :rtype: str
        """
        return self._advanced_snippet

    @advanced_snippet.setter
    def advanced_snippet(self, advanced_snippet):
        """Sets the advanced_snippet of this ConversionTrackerServiceAppLinkConversion.

        <div lang=\"ja\">   リニューアル版のコンバージョンタグは、従来のタグよりもブラウザーなどの環境の影響を受けづらい新しいフォーマットです。<br>   詳細は以下のヘルプを参照してください。<br>   ・<a href=\"https://ads-help.yahoo-net.jp/s/article/H000045014?language=ja\">コンバージョン測定とは</a><br>   このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">   The new format of conversion tag avoids the impacts such as changes made to the browser. <br>   See also the help below.<br>   * <a href=\"https://ads-help.yahoo-net.jp/s/article/H000045014?language=en_US\">Conversion Analytics</a><br>   Although this field will be returned in the response, it will be ignored on input. </div>   # noqa: E501

        :param advanced_snippet: The advanced_snippet of this ConversionTrackerServiceAppLinkConversion.  # noqa: E501
        :type: str
        """

        self._advanced_snippet = advanced_snippet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversionTrackerServiceAppLinkConversion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversionTrackerServiceAppLinkConversion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class KeywordPlanIdeaServiceSeed(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keyword_and_url_seed': 'KeywordPlanIdeaServiceKeywordAndUrlSeed',
        'keyword_seed': 'KeywordPlanIdeaServiceKeywordSeed',
        'url_seed': 'KeywordPlanIdeaServiceUrlSeed',
        'site_seed': 'KeywordPlanIdeaServiceSiteSeed',
        'seed_type': 'KeywordPlanIdeaServiceSeedType'
    }

    attribute_map = {
        'keyword_and_url_seed': 'keywordAndUrlSeed',
        'keyword_seed': 'keywordSeed',
        'url_seed': 'urlSeed',
        'site_seed': 'siteSeed',
        'seed_type': 'seedType'
    }

    def __init__(self, keyword_and_url_seed=None, keyword_seed=None, url_seed=None, site_seed=None, seed_type=None, local_vars_configuration=None):  # noqa: E501
        """KeywordPlanIdeaServiceSeed - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keyword_and_url_seed = None
        self._keyword_seed = None
        self._url_seed = None
        self._site_seed = None
        self._seed_type = None
        self.discriminator = None

        self.keyword_and_url_seed = keyword_and_url_seed
        self.keyword_seed = keyword_seed
        self.url_seed = url_seed
        self.site_seed = site_seed
        self.seed_type = seed_type

    @property
    def keyword_and_url_seed(self):
        """Gets the keyword_and_url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501


        :return: The keyword_and_url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :rtype: KeywordPlanIdeaServiceKeywordAndUrlSeed
        """
        return self._keyword_and_url_seed

    @keyword_and_url_seed.setter
    def keyword_and_url_seed(self, keyword_and_url_seed):
        """Sets the keyword_and_url_seed of this KeywordPlanIdeaServiceSeed.


        :param keyword_and_url_seed: The keyword_and_url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :type: KeywordPlanIdeaServiceKeywordAndUrlSeed
        """

        self._keyword_and_url_seed = keyword_and_url_seed

    @property
    def keyword_seed(self):
        """Gets the keyword_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501


        :return: The keyword_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :rtype: KeywordPlanIdeaServiceKeywordSeed
        """
        return self._keyword_seed

    @keyword_seed.setter
    def keyword_seed(self, keyword_seed):
        """Sets the keyword_seed of this KeywordPlanIdeaServiceSeed.


        :param keyword_seed: The keyword_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :type: KeywordPlanIdeaServiceKeywordSeed
        """

        self._keyword_seed = keyword_seed

    @property
    def url_seed(self):
        """Gets the url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501


        :return: The url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :rtype: KeywordPlanIdeaServiceUrlSeed
        """
        return self._url_seed

    @url_seed.setter
    def url_seed(self, url_seed):
        """Sets the url_seed of this KeywordPlanIdeaServiceSeed.


        :param url_seed: The url_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :type: KeywordPlanIdeaServiceUrlSeed
        """

        self._url_seed = url_seed

    @property
    def site_seed(self):
        """Gets the site_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501


        :return: The site_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :rtype: KeywordPlanIdeaServiceSiteSeed
        """
        return self._site_seed

    @site_seed.setter
    def site_seed(self, site_seed):
        """Sets the site_seed of this KeywordPlanIdeaServiceSeed.


        :param site_seed: The site_seed of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :type: KeywordPlanIdeaServiceSiteSeed
        """

        self._site_seed = site_seed

    @property
    def seed_type(self):
        """Gets the seed_type of this KeywordPlanIdeaServiceSeed.  # noqa: E501


        :return: The seed_type of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :rtype: KeywordPlanIdeaServiceSeedType
        """
        return self._seed_type

    @seed_type.setter
    def seed_type(self, seed_type):
        """Sets the seed_type of this KeywordPlanIdeaServiceSeed.


        :param seed_type: The seed_type of this KeywordPlanIdeaServiceSeed.  # noqa: E501
        :type: KeywordPlanIdeaServiceSeedType
        """

        self._seed_type = seed_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordPlanIdeaServiceSeed):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeywordPlanIdeaServiceSeed):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ad_type': 'AdGroupAdServiceAdType',
        'text_ad2': 'AdGroupAdServiceTextAd2',
        'app_ad': 'AdGroupAdServiceAppAd',
        'extended_text_ad': 'AdGroupAdServiceExtendedTextAd',
        'dynamic_search_linked_ad': 'AdGroupAdServiceDynamicSearchLinkedAd',
        'responsive_search_ad': 'AdGroupAdServiceResponsiveSearchAd',
        'final_url': 'str',
        'review_final_url': 'str',
        'smartphone_final_url': 'str',
        'review_smartphone_final_url': 'str',
        'is_remove_smartphone_final_url': 'AdGroupAdServiceIsRemove',
        'tracking_url': 'str',
        'review_tracking_url': 'str',
        'is_remove_tracking_url': 'AdGroupAdServiceIsRemove',
        'custom_parameters': 'AdGroupAdServiceCustomParameters',
        'review_custom_parameters': 'AdGroupAdServiceCustomParameters',
        'device_preference': 'AdGroupAdServiceDevicePreference',
        'display_url': 'str',
        'url': 'str'
    }

    attribute_map = {
        'ad_type': 'adType',
        'text_ad2': 'textAd2',
        'app_ad': 'appAd',
        'extended_text_ad': 'extendedTextAd',
        'dynamic_search_linked_ad': 'dynamicSearchLinkedAd',
        'responsive_search_ad': 'responsiveSearchAd',
        'final_url': 'finalUrl',
        'review_final_url': 'reviewFinalUrl',
        'smartphone_final_url': 'smartphoneFinalUrl',
        'review_smartphone_final_url': 'reviewSmartphoneFinalUrl',
        'is_remove_smartphone_final_url': 'isRemoveSmartphoneFinalUrl',
        'tracking_url': 'trackingUrl',
        'review_tracking_url': 'reviewTrackingUrl',
        'is_remove_tracking_url': 'isRemoveTrackingUrl',
        'custom_parameters': 'customParameters',
        'review_custom_parameters': 'reviewCustomParameters',
        'device_preference': 'devicePreference',
        'display_url': 'displayUrl',
        'url': 'url'
    }

    def __init__(self, ad_type=None, text_ad2=None, app_ad=None, extended_text_ad=None, dynamic_search_linked_ad=None, responsive_search_ad=None, final_url=None, review_final_url=None, smartphone_final_url=None, review_smartphone_final_url=None, is_remove_smartphone_final_url=None, tracking_url=None, review_tracking_url=None, is_remove_tracking_url=None, custom_parameters=None, review_custom_parameters=None, device_preference=None, display_url=None, url=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ad_type = None
        self._text_ad2 = None
        self._app_ad = None
        self._extended_text_ad = None
        self._dynamic_search_linked_ad = None
        self._responsive_search_ad = None
        self._final_url = None
        self._review_final_url = None
        self._smartphone_final_url = None
        self._review_smartphone_final_url = None
        self._is_remove_smartphone_final_url = None
        self._tracking_url = None
        self._review_tracking_url = None
        self._is_remove_tracking_url = None
        self._custom_parameters = None
        self._review_custom_parameters = None
        self._device_preference = None
        self._display_url = None
        self._url = None
        self.discriminator = None

        self.ad_type = ad_type
        self.text_ad2 = text_ad2
        self.app_ad = app_ad
        self.extended_text_ad = extended_text_ad
        self.dynamic_search_linked_ad = dynamic_search_linked_ad
        self.responsive_search_ad = responsive_search_ad
        self.final_url = final_url
        self.review_final_url = review_final_url
        self.smartphone_final_url = smartphone_final_url
        self.review_smartphone_final_url = review_smartphone_final_url
        self.is_remove_smartphone_final_url = is_remove_smartphone_final_url
        self.tracking_url = tracking_url
        self.review_tracking_url = review_tracking_url
        self.is_remove_tracking_url = is_remove_tracking_url
        self.custom_parameters = custom_parameters
        self.review_custom_parameters = review_custom_parameters
        self.device_preference = device_preference
        self.display_url = display_url
        self.url = url

    @property
    def ad_type(self):
        """Gets the ad_type of this AdGroupAdServiceAd.  # noqa: E501


        :return: The ad_type of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceAdType
        """
        return self._ad_type

    @ad_type.setter
    def ad_type(self, ad_type):
        """Sets the ad_type of this AdGroupAdServiceAd.


        :param ad_type: The ad_type of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceAdType
        """

        self._ad_type = ad_type

    @property
    def text_ad2(self):
        """Gets the text_ad2 of this AdGroupAdServiceAd.  # noqa: E501


        :return: The text_ad2 of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceTextAd2
        """
        return self._text_ad2

    @text_ad2.setter
    def text_ad2(self, text_ad2):
        """Sets the text_ad2 of this AdGroupAdServiceAd.


        :param text_ad2: The text_ad2 of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceTextAd2
        """

        self._text_ad2 = text_ad2

    @property
    def app_ad(self):
        """Gets the app_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The app_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceAppAd
        """
        return self._app_ad

    @app_ad.setter
    def app_ad(self, app_ad):
        """Sets the app_ad of this AdGroupAdServiceAd.


        :param app_ad: The app_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceAppAd
        """

        self._app_ad = app_ad

    @property
    def extended_text_ad(self):
        """Gets the extended_text_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The extended_text_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceExtendedTextAd
        """
        return self._extended_text_ad

    @extended_text_ad.setter
    def extended_text_ad(self, extended_text_ad):
        """Sets the extended_text_ad of this AdGroupAdServiceAd.


        :param extended_text_ad: The extended_text_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceExtendedTextAd
        """

        self._extended_text_ad = extended_text_ad

    @property
    def dynamic_search_linked_ad(self):
        """Gets the dynamic_search_linked_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The dynamic_search_linked_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceDynamicSearchLinkedAd
        """
        return self._dynamic_search_linked_ad

    @dynamic_search_linked_ad.setter
    def dynamic_search_linked_ad(self, dynamic_search_linked_ad):
        """Sets the dynamic_search_linked_ad of this AdGroupAdServiceAd.


        :param dynamic_search_linked_ad: The dynamic_search_linked_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceDynamicSearchLinkedAd
        """

        self._dynamic_search_linked_ad = dynamic_search_linked_ad

    @property
    def responsive_search_ad(self):
        """Gets the responsive_search_ad of this AdGroupAdServiceAd.  # noqa: E501


        :return: The responsive_search_ad of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceResponsiveSearchAd
        """
        return self._responsive_search_ad

    @responsive_search_ad.setter
    def responsive_search_ad(self, responsive_search_ad):
        """Sets the responsive_search_ad of this AdGroupAdServiceAd.


        :param responsive_search_ad: The responsive_search_ad of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceResponsiveSearchAd
        """

        self._responsive_search_ad = responsive_search_ad

    @property
    def final_url(self):
        """Gets the final_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">最終リンク先URLです。<br> ADD時、このフィールドは必須となります。※adTypeがDYNAMIC_SEARCH_LINKED_ADの場合は無視されます。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Landing page URL.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD, this field will be ignored.</div>   # noqa: E501

        :return: The final_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._final_url

    @final_url.setter
    def final_url(self, final_url):
        """Sets the final_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">最終リンク先URLです。<br> ADD時、このフィールドは必須となります。※adTypeがDYNAMIC_SEARCH_LINKED_ADの場合は無視されます。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Landing page URL.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD, this field will be ignored.</div>   # noqa: E501

        :param final_url: The final_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._final_url = final_url

    @property
    def review_final_url(self):
        """Gets the review_final_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._review_final_url

    @review_final_url.setter
    def review_final_url(self, review_final_url):
        """Sets the review_final_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_final_url: The review_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._review_final_url = review_final_url

    @property
    def smartphone_final_url(self):
        """Gets the smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADD時、このフィールドは省略可能となります。※adTypeがDYNAMIC_SEARCH_LINKED_ADの場合は無視されます。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD, this field will be ignored.</div>   # noqa: E501

        :return: The smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._smartphone_final_url

    @smartphone_final_url.setter
    def smartphone_final_url(self, smartphone_final_url):
        """Sets the smartphone_final_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADD時、このフィールドは省略可能となります。※adTypeがDYNAMIC_SEARCH_LINKED_ADの場合は無視されます。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD, this field will be ignored.</div>   # noqa: E501

        :param smartphone_final_url: The smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._smartphone_final_url = smartphone_final_url

    @property
    def review_smartphone_final_url(self):
        """Gets the review_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._review_smartphone_final_url

    @review_smartphone_final_url.setter
    def review_smartphone_final_url(self, review_smartphone_final_url):
        """Sets the review_smartphone_final_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_smartphone_final_url: The review_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._review_smartphone_final_url = review_smartphone_final_url

    @property
    def is_remove_smartphone_final_url(self):
        """Gets the is_remove_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501


        :return: The is_remove_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_smartphone_final_url

    @is_remove_smartphone_final_url.setter
    def is_remove_smartphone_final_url(self, is_remove_smartphone_final_url):
        """Sets the is_remove_smartphone_final_url of this AdGroupAdServiceAd.


        :param is_remove_smartphone_final_url: The is_remove_smartphone_final_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_smartphone_final_url = is_remove_smartphone_final_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADD時、このフィールドは省略可能となります。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD operation.</div>   # noqa: E501

        :return: The tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">トラッキングURLです。<br> ADD時、このフィールドは省略可能となります。<br> SET時、adTypeがRESPONSIVE_SEARCH_ADの場合のみ更新可能です。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD operation.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def review_tracking_url(self):
        """Gets the review_tracking_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._review_tracking_url

    @review_tracking_url.setter
    def review_tracking_url(self, review_tracking_url):
        """Sets the review_tracking_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_tracking_url: The review_tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._review_tracking_url = review_tracking_url

    @property
    def is_remove_tracking_url(self):
        """Gets the is_remove_tracking_url of this AdGroupAdServiceAd.  # noqa: E501


        :return: The is_remove_tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_tracking_url

    @is_remove_tracking_url.setter
    def is_remove_tracking_url(self, is_remove_tracking_url):
        """Sets the is_remove_tracking_url of this AdGroupAdServiceAd.


        :param is_remove_tracking_url: The is_remove_tracking_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_tracking_url = is_remove_tracking_url

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this AdGroupAdServiceAd.  # noqa: E501


        :return: The custom_parameters of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this AdGroupAdServiceAd.


        :param custom_parameters: The custom_parameters of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def review_custom_parameters(self):
        """Gets the review_custom_parameters of this AdGroupAdServiceAd.  # noqa: E501


        :return: The review_custom_parameters of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceCustomParameters
        """
        return self._review_custom_parameters

    @review_custom_parameters.setter
    def review_custom_parameters(self, review_custom_parameters):
        """Sets the review_custom_parameters of this AdGroupAdServiceAd.


        :param review_custom_parameters: The review_custom_parameters of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceCustomParameters
        """

        self._review_custom_parameters = review_custom_parameters

    @property
    def device_preference(self):
        """Gets the device_preference of this AdGroupAdServiceAd.  # noqa: E501


        :return: The device_preference of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: AdGroupAdServiceDevicePreference
        """
        return self._device_preference

    @device_preference.setter
    def device_preference(self, device_preference):
        """Sets the device_preference of this AdGroupAdServiceAd.


        :param device_preference: The device_preference of this AdGroupAdServiceAd.  # noqa: E501
        :type: AdGroupAdServiceDevicePreference
        """

        self._device_preference = device_preference

    @property
    def display_url(self):
        """Gets the display_url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">表示URLです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Display URL.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The display_url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._display_url

    @display_url.setter
    def display_url(self, display_url):
        """Sets the display_url of this AdGroupAdServiceAd.

        <div lang=\"ja\">表示URLです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Display URL.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param display_url: The display_url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._display_url = display_url

    @property
    def url(self):
        """Gets the url of this AdGroupAdServiceAd.  # noqa: E501

        <div lang=\"ja\">移行前のリンク先URLです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Destination URL before upgrading. <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The url of this AdGroupAdServiceAd.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AdGroupAdServiceAd.

        <div lang=\"ja\">移行前のリンク先URLです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Destination URL before upgrading. <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param url: The url of this AdGroupAdServiceAd.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class DictionaryServiceGeographicLocation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'child': 'list[DictionaryServiceGeographicLocation]',
        'code': 'str',
        'full_name': 'str',
        'geographic_location_status': 'DictionaryServiceGeographicLocationStatus',
        'name': 'str',
        'order': 'str',
        'parent': 'str'
    }

    attribute_map = {
        'child': 'child',
        'code': 'code',
        'full_name': 'fullName',
        'geographic_location_status': 'geographicLocationStatus',
        'name': 'name',
        'order': 'order',
        'parent': 'parent'
    }

    def __init__(self, child=None, code=None, full_name=None, geographic_location_status=None, name=None, order=None, parent=None, local_vars_configuration=None):  # noqa: E501
        """DictionaryServiceGeographicLocation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._child = None
        self._code = None
        self._full_name = None
        self._geographic_location_status = None
        self._name = None
        self._order = None
        self._parent = None
        self.discriminator = None

        self.child = child
        self.code = code
        self.full_name = full_name
        self.geographic_location_status = geographic_location_status
        self.name = name
        self.order = order
        self.parent = parent

    @property
    def child(self):
        """Gets the child of this DictionaryServiceGeographicLocation.  # noqa: E501


        :return: The child of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: list[DictionaryServiceGeographicLocation]
        """
        return self._child

    @child.setter
    def child(self, child):
        """Sets the child of this DictionaryServiceGeographicLocation.


        :param child: The child of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: list[DictionaryServiceGeographicLocation]
        """

        self._child = child

    @property
    def code(self):
        """Gets the code of this DictionaryServiceGeographicLocation.  # noqa: E501

        <div lang=\"ja\">地域コードです。</div> <div lang=\"en\">Geographic code.</div>   # noqa: E501

        :return: The code of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this DictionaryServiceGeographicLocation.

        <div lang=\"ja\">地域コードです。</div> <div lang=\"en\">Geographic code.</div>   # noqa: E501

        :param code: The code of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def full_name(self):
        """Gets the full_name of this DictionaryServiceGeographicLocation.  # noqa: E501

        <div lang=\"ja\">地域名(都道府県名からすべて)です。</div> <div lang=\"en\">Name of places (Prefecture and all).</div>   # noqa: E501

        :return: The full_name of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this DictionaryServiceGeographicLocation.

        <div lang=\"ja\">地域名(都道府県名からすべて)です。</div> <div lang=\"en\">Name of places (Prefecture and all).</div>   # noqa: E501

        :param full_name: The full_name of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def geographic_location_status(self):
        """Gets the geographic_location_status of this DictionaryServiceGeographicLocation.  # noqa: E501


        :return: The geographic_location_status of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: DictionaryServiceGeographicLocationStatus
        """
        return self._geographic_location_status

    @geographic_location_status.setter
    def geographic_location_status(self, geographic_location_status):
        """Sets the geographic_location_status of this DictionaryServiceGeographicLocation.


        :param geographic_location_status: The geographic_location_status of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: DictionaryServiceGeographicLocationStatus
        """

        self._geographic_location_status = geographic_location_status

    @property
    def name(self):
        """Gets the name of this DictionaryServiceGeographicLocation.  # noqa: E501

        <div lang=\"ja\">地域名(市区町村のみ)です。</div> <div lang=\"en\">Name of places (city only).</div>   # noqa: E501

        :return: The name of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DictionaryServiceGeographicLocation.

        <div lang=\"ja\">地域名(市区町村のみ)です。</div> <div lang=\"en\">Name of places (city only).</div>   # noqa: E501

        :param name: The name of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def order(self):
        """Gets the order of this DictionaryServiceGeographicLocation.  # noqa: E501

        <div lang=\"ja\">並び順です。<br>下記の順序に基づいた連番となります。<br> 都道府県は北海道、青森、・・・・沖縄の順<br>都道府県配下の市区町村は五十音順</div> <div lang=\"en\">Order of list<br><br>Sequential number based on the order below.<br><br> - Prefecture is in order of Hokkaido, Aomori to Okinawa. (North to South)<br><br> - Cities under prefecture are listed in the order of the 50-character Japanese kana syllabary.</div>   # noqa: E501

        :return: The order of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this DictionaryServiceGeographicLocation.

        <div lang=\"ja\">並び順です。<br>下記の順序に基づいた連番となります。<br> 都道府県は北海道、青森、・・・・沖縄の順<br>都道府県配下の市区町村は五十音順</div> <div lang=\"en\">Order of list<br><br>Sequential number based on the order below.<br><br> - Prefecture is in order of Hokkaido, Aomori to Okinawa. (North to South)<br><br> - Cities under prefecture are listed in the order of the 50-character Japanese kana syllabary.</div>   # noqa: E501

        :param order: The order of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: str
        """

        self._order = order

    @property
    def parent(self):
        """Gets the parent of this DictionaryServiceGeographicLocation.  # noqa: E501

        <div lang=\"ja\">上位地域コードです。</div> <div lang=\"en\">Parent geographic code.</div>   # noqa: E501

        :return: The parent of this DictionaryServiceGeographicLocation.  # noqa: E501
        :rtype: str
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this DictionaryServiceGeographicLocation.

        <div lang=\"ja\">上位地域コードです。</div> <div lang=\"en\">Parent geographic code.</div>   # noqa: E501

        :param parent: The parent of this DictionaryServiceGeographicLocation.  # noqa: E501
        :type: str
        """

        self._parent = parent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DictionaryServiceGeographicLocation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DictionaryServiceGeographicLocation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class Asset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'asset_id': 'int',
        'asset_track_id': 'int',
        'asset_data': 'AssetServiceAssetData',
        'approval_status': 'AssetServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]',
        'invalided_trademarks': 'list[str]',
        'trademark_status': 'AssetServiceTrademarkStatus',
        'custom_parameters': 'AssetServiceCustomParameters',
        'review_custom_parameters': 'AssetServiceCustomParameters',
        'smartphone_final_url': 'str',
        'review_smartphone_final_url': 'str',
        'final_url': 'str',
        'review_final_url': 'str',
        'tracking_url': 'str',
        'review_tracking_url': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'asset_id': 'assetId',
        'asset_track_id': 'assetTrackId',
        'asset_data': 'assetData',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'invalided_trademarks': 'invalidedTrademarks',
        'trademark_status': 'trademarkStatus',
        'custom_parameters': 'customParameters',
        'review_custom_parameters': 'reviewCustomParameters',
        'smartphone_final_url': 'smartphoneFinalUrl',
        'review_smartphone_final_url': 'reviewSmartphoneFinalUrl',
        'final_url': 'finalUrl',
        'review_final_url': 'reviewFinalUrl',
        'tracking_url': 'trackingUrl',
        'review_tracking_url': 'reviewTrackingUrl'
    }

    def __init__(self, account_id=None, asset_id=None, asset_track_id=None, asset_data=None, approval_status=None, disapproval_reason_codes=None, invalided_trademarks=None, trademark_status=None, custom_parameters=None, review_custom_parameters=None, smartphone_final_url=None, review_smartphone_final_url=None, final_url=None, review_final_url=None, tracking_url=None, review_tracking_url=None, local_vars_configuration=None):  # noqa: E501
        """Asset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._asset_id = None
        self._asset_track_id = None
        self._asset_data = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self._invalided_trademarks = None
        self._trademark_status = None
        self._custom_parameters = None
        self._review_custom_parameters = None
        self._smartphone_final_url = None
        self._review_smartphone_final_url = None
        self._final_url = None
        self._review_final_url = None
        self._tracking_url = None
        self._review_tracking_url = None
        self.discriminator = None

        self.account_id = account_id
        self.asset_id = asset_id
        self.asset_track_id = asset_track_id
        self.asset_data = asset_data
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes
        self.invalided_trademarks = invalided_trademarks
        self.trademark_status = trademark_status
        self.custom_parameters = custom_parameters
        self.review_custom_parameters = review_custom_parameters
        self.smartphone_final_url = smartphone_final_url
        self.review_smartphone_final_url = review_smartphone_final_url
        self.final_url = final_url
        self.review_final_url = review_final_url
        self.tracking_url = tracking_url
        self.review_tracking_url = review_tracking_url

    @property
    def account_id(self):
        """Gets the account_id of this Asset.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Asset.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this Asset.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def asset_id(self):
        """Gets the asset_id of this Asset.  # noqa: E501

        <div lang=\"ja\">アセットIDです。<br> このフィールドは、SETおよびREMOVE時に必須となり、ADD時に無視されます。</div> <div lang=\"en\">Asset ID.<br>This field is required in SET and REMOVE operation, and will be ignored in ADD operation.</div>   # noqa: E501

        :return: The asset_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this Asset.

        <div lang=\"ja\">アセットIDです。<br> このフィールドは、SETおよびREMOVE時に必須となり、ADD時に無視されます。</div> <div lang=\"en\">Asset ID.<br>This field is required in SET and REMOVE operation, and will be ignored in ADD operation.</div>   # noqa: E501

        :param asset_id: The asset_id of this Asset.  # noqa: E501
        :type: int
        """

        self._asset_id = asset_id

    @property
    def asset_track_id(self):
        """Gets the asset_track_id of this Asset.  # noqa: E501

        <div lang=\"ja\">トラッキング用アセットIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Asset ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The asset_track_id of this Asset.  # noqa: E501
        :rtype: int
        """
        return self._asset_track_id

    @asset_track_id.setter
    def asset_track_id(self, asset_track_id):
        """Sets the asset_track_id of this Asset.

        <div lang=\"ja\">トラッキング用アセットIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Asset ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param asset_track_id: The asset_track_id of this Asset.  # noqa: E501
        :type: int
        """

        self._asset_track_id = asset_track_id

    @property
    def asset_data(self):
        """Gets the asset_data of this Asset.  # noqa: E501


        :return: The asset_data of this Asset.  # noqa: E501
        :rtype: AssetServiceAssetData
        """
        return self._asset_data

    @asset_data.setter
    def asset_data(self, asset_data):
        """Sets the asset_data of this Asset.


        :param asset_data: The asset_data of this Asset.  # noqa: E501
        :type: AssetServiceAssetData
        """

        self._asset_data = asset_data

    @property
    def approval_status(self):
        """Gets the approval_status of this Asset.  # noqa: E501


        :return: The approval_status of this Asset.  # noqa: E501
        :rtype: AssetServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this Asset.


        :param approval_status: The approval_status of this Asset.  # noqa: E501
        :type: AssetServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this Asset.  # noqa: E501

        <div lang=\"ja\">審査否認理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this Asset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this Asset.

        <div lang=\"ja\">審査否認理由です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Reject reason on editorial review.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this Asset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def invalided_trademarks(self):
        """Gets the invalided_trademarks of this Asset.  # noqa: E501

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The invalided_trademarks of this Asset.  # noqa: E501
        :rtype: list[str]
        """
        return self._invalided_trademarks

    @invalided_trademarks.setter
    def invalided_trademarks(self, invalided_trademarks):
        """Sets the invalided_trademarks of this Asset.

        <div lang=\"ja\">制限された商標です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。 </div> <div lang=\"en\">Invalided trademarks.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param invalided_trademarks: The invalided_trademarks of this Asset.  # noqa: E501
        :type: list[str]
        """

        self._invalided_trademarks = invalided_trademarks

    @property
    def trademark_status(self):
        """Gets the trademark_status of this Asset.  # noqa: E501


        :return: The trademark_status of this Asset.  # noqa: E501
        :rtype: AssetServiceTrademarkStatus
        """
        return self._trademark_status

    @trademark_status.setter
    def trademark_status(self, trademark_status):
        """Sets the trademark_status of this Asset.


        :param trademark_status: The trademark_status of this Asset.  # noqa: E501
        :type: AssetServiceTrademarkStatus
        """

        self._trademark_status = trademark_status

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this Asset.  # noqa: E501


        :return: The custom_parameters of this Asset.  # noqa: E501
        :rtype: AssetServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this Asset.


        :param custom_parameters: The custom_parameters of this Asset.  # noqa: E501
        :type: AssetServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def review_custom_parameters(self):
        """Gets the review_custom_parameters of this Asset.  # noqa: E501


        :return: The review_custom_parameters of this Asset.  # noqa: E501
        :rtype: AssetServiceCustomParameters
        """
        return self._review_custom_parameters

    @review_custom_parameters.setter
    def review_custom_parameters(self, review_custom_parameters):
        """Sets the review_custom_parameters of this Asset.


        :param review_custom_parameters: The review_custom_parameters of this Asset.  # noqa: E501
        :type: AssetServiceCustomParameters
        """

        self._review_custom_parameters = review_custom_parameters

    @property
    def smartphone_final_url(self):
        """Gets the smartphone_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :return: The smartphone_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._smartphone_final_url

    @smartphone_final_url.setter
    def smartphone_final_url(self, smartphone_final_url):
        """Sets the smartphone_final_url of this Asset.

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Landing page URL (Smartphone).<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :param smartphone_final_url: The smartphone_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._smartphone_final_url = smartphone_final_url

    @property
    def review_smartphone_final_url(self):
        """Gets the review_smartphone_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_smartphone_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_smartphone_final_url

    @review_smartphone_final_url.setter
    def review_smartphone_final_url(self, review_smartphone_final_url):
        """Sets the review_smartphone_final_url of this Asset.

        <div lang=\"ja\">審査中の最終リンク先URL（スマートフォン）です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL (Smartphone) on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_smartphone_final_url: The review_smartphone_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_smartphone_final_url = review_smartphone_final_url

    @property
    def final_url(self):
        """Gets the final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">最終リンク先URLです。<br> ADDおよびSET時、assetData.typeがQUICKLINKの場合は必須です。<br> assetData.typeがQUICKLINK以外の場合、リクエストの際に無視されます。</div> <div lang=\"en\">Landing page URL.<br> This field is optional in ADD and SET operation.<br> In ADD and SET operation, If assetData.type is QUICKLINK, this field is required.<br> And will be ignored when assetData.type is the others.</div>   # noqa: E501

        :return: The final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._final_url

    @final_url.setter
    def final_url(self, final_url):
        """Sets the final_url of this Asset.

        <div lang=\"ja\">最終リンク先URLです。<br> ADDおよびSET時、assetData.typeがQUICKLINKの場合は必須です。<br> assetData.typeがQUICKLINK以外の場合、リクエストの際に無視されます。</div> <div lang=\"en\">Landing page URL.<br> This field is optional in ADD and SET operation.<br> In ADD and SET operation, If assetData.type is QUICKLINK, this field is required.<br> And will be ignored when assetData.type is the others.</div>   # noqa: E501

        :param final_url: The final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._final_url = final_url

    @property
    def review_final_url(self):
        """Gets the review_final_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_final_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_final_url

    @review_final_url.setter
    def review_final_url(self, review_final_url):
        """Sets the review_final_url of this Asset.

        <div lang=\"ja\">審査中の最終リンク先URLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Landing page URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_final_url: The review_final_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_final_url = review_final_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this Asset.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :return: The tracking_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this Asset.

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this Asset.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def review_tracking_url(self):
        """Gets the review_tracking_url of this Asset.  # noqa: E501

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_tracking_url of this Asset.  # noqa: E501
        :rtype: str
        """
        return self._review_tracking_url

    @review_tracking_url.setter
    def review_tracking_url(self, review_tracking_url):
        """Sets the review_tracking_url of this Asset.

        <div lang=\"ja\">審査中のトラッキングURLです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Tracking URL on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_tracking_url: The review_tracking_url of this Asset.  # noqa: E501
        :type: str
        """

        self._review_tracking_url = review_tracking_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Asset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Asset):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AppLink(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'app_link_id': 'int',
        'app_vendor_id': 'str',
        'app_vendor_name_ja': 'str',
        'app_vendor_name_en': 'str',
        'app_id': 'str',
        'app_link_platform': 'AppLinkServiceAppLinkPlatform',
        'link_id': 'str',
        'link_status': 'AppLinkServiceLinkStatus',
        'sync_status': 'AppLinkServiceSyncStatus'
    }

    attribute_map = {
        'account_id': 'accountId',
        'app_link_id': 'appLinkId',
        'app_vendor_id': 'appVendorId',
        'app_vendor_name_ja': 'appVendorNameJa',
        'app_vendor_name_en': 'appVendorNameEn',
        'app_id': 'appId',
        'app_link_platform': 'appLinkPlatform',
        'link_id': 'linkId',
        'link_status': 'linkStatus',
        'sync_status': 'syncStatus'
    }

    def __init__(self, account_id=None, app_link_id=None, app_vendor_id=None, app_vendor_name_ja=None, app_vendor_name_en=None, app_id=None, app_link_platform=None, link_id=None, link_status=None, sync_status=None, local_vars_configuration=None):  # noqa: E501
        """AppLink - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._app_link_id = None
        self._app_vendor_id = None
        self._app_vendor_name_ja = None
        self._app_vendor_name_en = None
        self._app_id = None
        self._app_link_platform = None
        self._link_id = None
        self._link_status = None
        self._sync_status = None
        self.discriminator = None

        self.account_id = account_id
        self.app_link_id = app_link_id
        self.app_vendor_id = app_vendor_id
        self.app_vendor_name_ja = app_vendor_name_ja
        self.app_vendor_name_en = app_vendor_name_en
        self.app_id = app_id
        self.app_link_platform = app_link_platform
        self.link_id = link_id
        self.link_status = link_status
        self.sync_status = sync_status

    @property
    def account_id(self):
        """Gets the account_id of this AppLink.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this AppLink.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AppLink.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this AppLink.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def app_link_id(self):
        """Gets the app_link_id of this AppLink.  # noqa: E501

        <div lang=\"ja\">アプリリンクIDです。<br> SETまたはREGENERATE時、このフィールドは必須となります。</div> <div lang=\"en\">App link ID.<br> This field is required in SET or REGENERATE operation.</div>   # noqa: E501

        :return: The app_link_id of this AppLink.  # noqa: E501
        :rtype: int
        """
        return self._app_link_id

    @app_link_id.setter
    def app_link_id(self, app_link_id):
        """Sets the app_link_id of this AppLink.

        <div lang=\"ja\">アプリリンクIDです。<br> SETまたはREGENERATE時、このフィールドは必須となります。</div> <div lang=\"en\">App link ID.<br> This field is required in SET or REGENERATE operation.</div>   # noqa: E501

        :param app_link_id: The app_link_id of this AppLink.  # noqa: E501
        :type: int
        """

        self._app_link_id = app_link_id

    @property
    def app_vendor_id(self):
        """Gets the app_vendor_id of this AppLink.  # noqa: E501

        <div lang=\"ja\">アプリ計測ベンダーIDです。<br> ADD時、このフィールドは必須となります。<br> ※DictionaryService/getAppLinkVendorで取得できるappVendorIdのみ使用できます。</div> <div lang=\"en\">App vendor ID.<br> This field is required in ADD operation.<br> *Only the appVendorId that can be obtained with DictionaryService/getAppLinkVendor can be used.</div>   # noqa: E501

        :return: The app_vendor_id of this AppLink.  # noqa: E501
        :rtype: str
        """
        return self._app_vendor_id

    @app_vendor_id.setter
    def app_vendor_id(self, app_vendor_id):
        """Sets the app_vendor_id of this AppLink.

        <div lang=\"ja\">アプリ計測ベンダーIDです。<br> ADD時、このフィールドは必須となります。<br> ※DictionaryService/getAppLinkVendorで取得できるappVendorIdのみ使用できます。</div> <div lang=\"en\">App vendor ID.<br> This field is required in ADD operation.<br> *Only the appVendorId that can be obtained with DictionaryService/getAppLinkVendor can be used.</div>   # noqa: E501

        :param app_vendor_id: The app_vendor_id of this AppLink.  # noqa: E501
        :type: str
        """

        self._app_vendor_id = app_vendor_id

    @property
    def app_vendor_name_ja(self):
        """Gets the app_vendor_name_ja of this AppLink.  # noqa: E501

        <div lang=\"ja\">アプリ計測ベンダー名（日本語）です。</div> <div lang=\"en\">App vendor name in Japanese.</div>   # noqa: E501

        :return: The app_vendor_name_ja of this AppLink.  # noqa: E501
        :rtype: str
        """
        return self._app_vendor_name_ja

    @app_vendor_name_ja.setter
    def app_vendor_name_ja(self, app_vendor_name_ja):
        """Sets the app_vendor_name_ja of this AppLink.

        <div lang=\"ja\">アプリ計測ベンダー名（日本語）です。</div> <div lang=\"en\">App vendor name in Japanese.</div>   # noqa: E501

        :param app_vendor_name_ja: The app_vendor_name_ja of this AppLink.  # noqa: E501
        :type: str
        """

        self._app_vendor_name_ja = app_vendor_name_ja

    @property
    def app_vendor_name_en(self):
        """Gets the app_vendor_name_en of this AppLink.  # noqa: E501

        <div lang=\"ja\">アプリ計測ベンダー名（英語）です。</div> <div lang=\"en\">App vendor name in English.</div>   # noqa: E501

        :return: The app_vendor_name_en of this AppLink.  # noqa: E501
        :rtype: str
        """
        return self._app_vendor_name_en

    @app_vendor_name_en.setter
    def app_vendor_name_en(self, app_vendor_name_en):
        """Sets the app_vendor_name_en of this AppLink.

        <div lang=\"ja\">アプリ計測ベンダー名（英語）です。</div> <div lang=\"en\">App vendor name in English.</div>   # noqa: E501

        :param app_vendor_name_en: The app_vendor_name_en of this AppLink.  # noqa: E501
        :type: str
        """

        self._app_vendor_name_en = app_vendor_name_en

    @property
    def app_id(self):
        """Gets the app_id of this AppLink.  # noqa: E501

        <div lang=\"ja\">アプリIDです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">App ID.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The app_id of this AppLink.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this AppLink.

        <div lang=\"ja\">アプリIDです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">App ID.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param app_id: The app_id of this AppLink.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def app_link_platform(self):
        """Gets the app_link_platform of this AppLink.  # noqa: E501


        :return: The app_link_platform of this AppLink.  # noqa: E501
        :rtype: AppLinkServiceAppLinkPlatform
        """
        return self._app_link_platform

    @app_link_platform.setter
    def app_link_platform(self, app_link_platform):
        """Sets the app_link_platform of this AppLink.


        :param app_link_platform: The app_link_platform of this AppLink.  # noqa: E501
        :type: AppLinkServiceAppLinkPlatform
        """

        self._app_link_platform = app_link_platform

    @property
    def link_id(self):
        """Gets the link_id of this AppLink.  # noqa: E501

        <div lang=\"ja\">リンクIDです。</div> <div lang=\"en\">Link ID.</div>   # noqa: E501

        :return: The link_id of this AppLink.  # noqa: E501
        :rtype: str
        """
        return self._link_id

    @link_id.setter
    def link_id(self, link_id):
        """Sets the link_id of this AppLink.

        <div lang=\"ja\">リンクIDです。</div> <div lang=\"en\">Link ID.</div>   # noqa: E501

        :param link_id: The link_id of this AppLink.  # noqa: E501
        :type: str
        """

        self._link_id = link_id

    @property
    def link_status(self):
        """Gets the link_status of this AppLink.  # noqa: E501


        :return: The link_status of this AppLink.  # noqa: E501
        :rtype: AppLinkServiceLinkStatus
        """
        return self._link_status

    @link_status.setter
    def link_status(self, link_status):
        """Sets the link_status of this AppLink.


        :param link_status: The link_status of this AppLink.  # noqa: E501
        :type: AppLinkServiceLinkStatus
        """

        self._link_status = link_status

    @property
    def sync_status(self):
        """Gets the sync_status of this AppLink.  # noqa: E501


        :return: The sync_status of this AppLink.  # noqa: E501
        :rtype: AppLinkServiceSyncStatus
        """
        return self._sync_status

    @sync_status.setter
    def sync_status(self, sync_status):
        """Sets the sync_status of this AppLink.


        :param sync_status: The sync_status of this AppLink.  # noqa: E501
        :type: AppLinkServiceSyncStatus
        """

        self._sync_status = sync_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppLink):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AppLink):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AccountManagementServiceSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_ids': 'list[int]',
        'account_statuses': 'list[AccountManagementServiceStatus]',
        'account_types': 'list[AccountManagementServicePaymentType]',
        'include_test_account': 'AccountManagementServiceIncludeTestAccount',
        'number_results': 'int',
        'start_index': 'int'
    }

    attribute_map = {
        'account_ids': 'accountIds',
        'account_statuses': 'accountStatuses',
        'account_types': 'accountTypes',
        'include_test_account': 'includeTestAccount',
        'number_results': 'numberResults',
        'start_index': 'startIndex'
    }

    def __init__(self, account_ids=None, account_statuses=None, account_types=None, include_test_account=None, number_results=200, start_index=1, local_vars_configuration=None):  # noqa: E501
        """AccountManagementServiceSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_ids = None
        self._account_statuses = None
        self._account_types = None
        self._include_test_account = None
        self._number_results = None
        self._start_index = None
        self.discriminator = None

        self.account_ids = account_ids
        self.account_statuses = account_statuses
        self.account_types = account_types
        self.include_test_account = include_test_account
        self.number_results = number_results
        self.start_index = start_index

    @property
    def account_ids(self):
        """Gets the account_ids of this AccountManagementServiceSelector.  # noqa: E501

        <div lang=\"ja\">検索条件：アカウントID</div> <div lang=\"en\">Account IDs.</div>   # noqa: E501

        :return: The account_ids of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: list[int]
        """
        return self._account_ids

    @account_ids.setter
    def account_ids(self, account_ids):
        """Sets the account_ids of this AccountManagementServiceSelector.

        <div lang=\"ja\">検索条件：アカウントID</div> <div lang=\"en\">Account IDs.</div>   # noqa: E501

        :param account_ids: The account_ids of this AccountManagementServiceSelector.  # noqa: E501
        :type: list[int]
        """

        self._account_ids = account_ids

    @property
    def account_statuses(self):
        """Gets the account_statuses of this AccountManagementServiceSelector.  # noqa: E501

        <div lang=\"ja\">検索条件：アカウントステータス</div> <div lang=\"en\">Account statuses.</div>   # noqa: E501

        :return: The account_statuses of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: list[AccountManagementServiceStatus]
        """
        return self._account_statuses

    @account_statuses.setter
    def account_statuses(self, account_statuses):
        """Sets the account_statuses of this AccountManagementServiceSelector.

        <div lang=\"ja\">検索条件：アカウントステータス</div> <div lang=\"en\">Account statuses.</div>   # noqa: E501

        :param account_statuses: The account_statuses of this AccountManagementServiceSelector.  # noqa: E501
        :type: list[AccountManagementServiceStatus]
        """

        self._account_statuses = account_statuses

    @property
    def account_types(self):
        """Gets the account_types of this AccountManagementServiceSelector.  # noqa: E501

        <div lang=\"ja\">検索条件：アカウントの料金支払い種別</div> <div lang=\"en\">Account payment types.</div>   # noqa: E501

        :return: The account_types of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: list[AccountManagementServicePaymentType]
        """
        return self._account_types

    @account_types.setter
    def account_types(self, account_types):
        """Sets the account_types of this AccountManagementServiceSelector.

        <div lang=\"ja\">検索条件：アカウントの料金支払い種別</div> <div lang=\"en\">Account payment types.</div>   # noqa: E501

        :param account_types: The account_types of this AccountManagementServiceSelector.  # noqa: E501
        :type: list[AccountManagementServicePaymentType]
        """

        self._account_types = account_types

    @property
    def include_test_account(self):
        """Gets the include_test_account of this AccountManagementServiceSelector.  # noqa: E501


        :return: The include_test_account of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: AccountManagementServiceIncludeTestAccount
        """
        return self._include_test_account

    @include_test_account.setter
    def include_test_account(self, include_test_account):
        """Sets the include_test_account of this AccountManagementServiceSelector.


        :param include_test_account: The include_test_account of this AccountManagementServiceSelector.  # noqa: E501
        :type: AccountManagementServiceIncludeTestAccount
        """

        self._include_test_account = include_test_account

    @property
    def number_results(self):
        """Gets the number_results of this AccountManagementServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :return: The number_results of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._number_results

    @number_results.setter
    def number_results(self, number_results):
        """Sets the number_results of this AccountManagementServiceSelector.

        <div lang=\"ja\">ページの最大件数です。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Maximum number of results to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :param number_results: The number_results of this AccountManagementServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results > 200):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value less than or equal to `200`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_results is not None and number_results < 1):  # noqa: E501
            raise ValueError("Invalid value for `number_results`, must be a value greater than or equal to `1`")  # noqa: E501

        self._number_results = number_results

    @property
    def start_index(self):
        """Gets the start_index of this AccountManagementServiceSelector.  # noqa: E501

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :return: The start_index of this AccountManagementServiceSelector.  # noqa: E501
        :rtype: int
        """
        return self._start_index

    @start_index.setter
    def start_index(self, start_index):
        """Sets the start_index of this AccountManagementServiceSelector.

        <div lang=\"ja\">ページの先頭のインデックスです。このフィールドは、1以上を指定する必要があります。</div> <div lang=\"en\">Index of the first result to return in this page. This field must be greater than or equal to 1.</div>   # noqa: E501

        :param start_index: The start_index of this AccountManagementServiceSelector.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                start_index is not None and start_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `start_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._start_index = start_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountManagementServiceSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountManagementServiceSelector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAssetSetServicePage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'total_num_entries': 'int',
        'values': 'list[PageFeedAssetSetServiceValue]'
    }

    attribute_map = {
        'total_num_entries': 'totalNumEntries',
        'values': 'values'
    }

    def __init__(self, total_num_entries=None, values=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAssetSetServicePage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._total_num_entries = None
        self._values = None
        self.discriminator = None

        if total_num_entries is not None:
            self.total_num_entries = total_num_entries
        self.values = values

    @property
    def total_num_entries(self):
        """Gets the total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501

        <div lang=\"ja\">取得される項目の総件数です。</div> <div lang=\"en\">Total number of entries in the result that this page is a part of.</div>   # noqa: E501

        :return: The total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501
        :rtype: int
        """
        return self._total_num_entries

    @total_num_entries.setter
    def total_num_entries(self, total_num_entries):
        """Sets the total_num_entries of this PageFeedAssetSetServicePage.

        <div lang=\"ja\">取得される項目の総件数です。</div> <div lang=\"en\">Total number of entries in the result that this page is a part of.</div>   # noqa: E501

        :param total_num_entries: The total_num_entries of this PageFeedAssetSetServicePage.  # noqa: E501
        :type: int
        """

        self._total_num_entries = total_num_entries

    @property
    def values(self):
        """Gets the values of this PageFeedAssetSetServicePage.  # noqa: E501


        :return: The values of this PageFeedAssetSetServicePage.  # noqa: E501
        :rtype: list[PageFeedAssetSetServiceValue]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this PageFeedAssetSetServicePage.


        :param values: The values of this PageFeedAssetSetServicePage.  # noqa: E501
        :type: list[PageFeedAssetSetServiceValue]
        """

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAssetSetServicePage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAssetSetServicePage):
            return True

        return self.to_dict() != other.to_dict()
